/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global window*/

/**
 * Application option model module.
 * It is responsible for storing information about active option.
 * It is also responsible for notification about active option changes.
 *
 * @module app.model.option
 * @requires {@link app.common.events}
 * @namespace app.model.option
 * @memberof app.model
 */

// make sure that "app" namespace is created
window.app = window.app || {};

(function defineAppModelOption(app) {
    'use strict';

    /**
     * Common events module reference.
     *
     * @memberof app.model.option
     * @private
     * @type {object}
     */
    var commonEvents = app.common.events,

        /**
         * Active option name.
         *
         * @memberof app.model.option
         * @private
         * @type {string}
         */
        option = '';

    /**
     * Sets active option name.
     *
     * @memberof app.model.option
     * @public
     * @param {string} name
     * @fires "option.changed"
     */
    function setOption(name) {
        if (option !== name) {
            option = name;
            commonEvents.dispatchEvent('option.changed', {name: name});
        }
    }

    /**
     * Returns active option name.
     *
     * @memberof app.model.option
     * @public
     * @returns {string}
     */
    function getOption() {
        return option;
    }

    /**
     * Resets active option name.
     *
     * @memberof app.model.option
     * @public
     */
    function resetOption() {
        option = '';
    }

    app.model = app.model || {};
    app.model.option = {
        setOption: setOption,
        getOption: getOption,
        resetOption: resetOption
    };

})(window.app);
